<?php
$process = new Swoole\Process(function (Swoole\Process $worker)
{
    echo "Worker: start. PID=" . $worker->pid . "\n";
    sleep(2);
    $worker->write("hello master\n");
    $worker->exit(0);
}, false);

$pid = $process->start();
$r = array($process);
$ret = swoole_select($r, null, null, 1.0);
var_dump($ret);
var_dump($process->read());
